module PDFire
  class ApiError
    attr_reader :message
  end

  class RequestError < StandardError
    attr_reader :errors
    attr_reader :message

    def initialize(errors, default = 'Request error.')
      @errors = errors
      @message = errors.length == 0 ? errors[0].message : default
    end
  end

  class BadRequestError < RequestError
    def initialize(errors)
      super(errors, 'Bad request.')
    end
  end

  class UnauthorizedError < RequestError
    def initialize(errors)
      super(errors, 'Unauthorized.')
    end
  end

  class QuotaError < RequestError
    def initialize(errors)
      super(errors, 'Quota exceeded.')
    end
  end

  class ForbiddenActionError < RequestError
    def initialize(errors)
      super(errors, 'Forbidden action.')
    end
  end

  class ConversionError < RequestError
    def initialize(errors)
      super(errors, 'Conversion failed.')
    end
  end
end
